@@ -1,7 +1,7 @@
 require(fitdistrplus)
 
 #case where the density returns a Not-an-Numeric value.
-detectbound("gamma", c(shape=3, scale=3), 1:10)
+detectbound("gamma", c(shape=3, scale=3), 1:10, echo=TRUE)
 detectbound("logis", c(location=3, scale=3), 1:10)
 detectbound("geom", c(prob=1/2), 1:10)
 
